# Pulumi Terraform Provider

The Terraform resource provider for Pulumi lets you consume the outputs contained in
Terraform state files from your Pulumi programs. 

> [!IMPORTANT]
> For reference docs and installation instructions, please go to
> <https://www.pulumi.com/registry/packages/terraform/>.
